@@ -1,5 +1,5 @@
 from starlette_context.header_keys import HeaderKeys
-from starlette_context.plugins.plugin_uuid import PluginUUIDBase
+from starlette_context.plugins.base import PluginUUIDBase
 
 
 class CorrelationIdPlugin(PluginUUIDBase):
